==> huaweicloudsdkcc-3.1.126-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/site_network_quota_key.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SiteNetworkQuotaKey:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'quota_key': 'SiteNetworkQuotaKeyEnum'
    }

    attribute_map = {
        'quota_key': 'quota_key'
    }

    def __init__(self, quota_key=None):
        """SiteNetworkQuotaKey

        The model defined in huaweicloud sdk

        :param quota_key: 
        :type quota_key: :class:`huaweicloudsdkcc.v3.SiteNetworkQuotaKeyEnum`
        """
        
        

        self._quota_key = None
        self.discriminator = None

        self.quota_key = quota_key

    @property
    def quota_key(self):
        """Gets the quota_key of this SiteNetworkQuotaKey.

        :return: The quota_key of this SiteNetworkQuotaKey.
        :rtype: :class:`huaweicloudsdkcc.v3.SiteNetworkQuotaKeyEnum`
        """
        return self._quota_key

    @quota_key.setter
    def quota_key(self, quota_key):
        """Sets the quota_key of this SiteNetworkQuotaKey.

        :param quota_key: The quota_key of this SiteNetworkQuotaKey.
        :type quota_key: :class:`huaweicloudsdkcc.v3.SiteNetworkQuotaKeyEnum`
        """
        self._quota_key = quota_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SiteNetworkQuotaKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcc-3.1.153-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/site_network_quota_key.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SiteNetworkQuotaKey:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'quota_key': 'SiteNetworkQuotaKeyEnum'
    }

    attribute_map = {
        'quota_key': 'quota_key'
    }

    def __init__(self, quota_key=None):
        r"""SiteNetworkQuotaKey

        The model defined in huaweicloud sdk

        :param quota_key: 
        :type quota_key: :class:`huaweicloudsdkcc.v3.SiteNetworkQuotaKeyEnum`
        """
        
        

        self._quota_key = None
        self.discriminator = None

        self.quota_key = quota_key

    @property
    def quota_key(self):
        r"""Gets the quota_key of this SiteNetworkQuotaKey.

        :return: The quota_key of this SiteNetworkQuotaKey.
        :rtype: :class:`huaweicloudsdkcc.v3.SiteNetworkQuotaKeyEnum`
        """
        return self._quota_key

    @quota_key.setter
    def quota_key(self, quota_key):
        r"""Sets the quota_key of this SiteNetworkQuotaKey.

        :param quota_key: The quota_key of this SiteNetworkQuotaKey.
        :type quota_key: :class:`huaweicloudsdkcc.v3.SiteNetworkQuotaKeyEnum`
        """
        self._quota_key = quota_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SiteNetworkQuotaKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
